from extras.plugins import PluginMenuItem

menu_items = (
    PluginMenuItem(
        link='plugins:netbox_textdatastore:textdataobject_list',
        link_text='Raw Data'
    ),
)
